@@ -1,6 +1,6 @@
 /* Parse command line arguments for bison.
 
-   Copyright (C) 1984, 1986, 1989, 1992, 2000-2015, 2018-2019 Free
+   Copyright (C) 1984, 1986, 1989, 1992, 2000-2015, 2018-2020 Free
    Software Foundation, Inc.
 
    This file is part of Bison, the GNU Compiler Compiler.
@@ -118,7 +118,7 @@ enum feature
   {
     feature_none             = 0,      /**< No additional feature.  */
     feature_caret            = 1 << 0, /**< Output errors with carets.  */
-    feature_fixit_parsable   = 1 << 1, /**< Issue instructions to fix the sources.  */
+    feature_fixit            = 1 << 1, /**< Issue instructions to fix the sources.  */
     feature_syntax_only      = 1 << 2, /**< Don't generate output.  */
     feature_all              = ~0      /**< All above features.  */
   };
